package com.four.system.api.factory;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;
import com.four.common.core.domain.R;
import com.four.system.api.RemoteUserService;
import com.four.system.api.domain.SysUser;
import com.four.system.api.model.LoginUser;

/**
 * 用户服务降级处理
 *
 * @author ruoyi
 */
@Component
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService>
{
    private static final Logger log = LoggerFactory.getLogger(RemoteUserFallbackFactory.class);

    @Override
    public RemoteUserService create(Throwable throwable)
    {
        log.error("用户服务调用失败:{}", throwable.getMessage());
        return new RemoteUserService()
        {


            /***
             *获取用户信息
             * @param email 用户名
             * @param source 请求来源
             * @return
             */
            @Override
            public R<LoginUser> getUserInfoByEmail(String email, String source) {
                return R.fail("获取用户信息失败："+  throwable.getMessage());
            }

            /***
             * 查询用户信息
             * @param userName 用户名
             * @param source 请求来源
             * @return
             */
            @Override
            public R<LoginUser> getUserInfo(String userName,String source){
                return R.fail("获取用户失败:"+throwable.getMessage());
            }

            /***
             * 欧通用户注册
             * @param sysUser
             * @param source
             * @return
             */
            @Override
            public R<Boolean> registerUserInfo(SysUser sysUser, String source)
            {
                return R.fail("注册用户失败:" + throwable.getMessage());
            }

            /***
             * 医生注册
             * @param sysUser
             * @param source 请求来源
             * @return
             */
            @Override
            public R<Boolean> healthRegister(SysUser sysUser, String source) {
                return R.fail("医生用户失败:" + throwable.getMessage());
            }

            /***
             * 用户注册
             * @param sysUser
             * @param source
             * @return
             */
            @Override
            public R<Boolean> PatientRegisterBody(SysUser sysUser, String source) {
                return R.fail("患者用户失败：" + throwable.getMessage());
            }

            @Override
            public R<Boolean> emailLogin(SysUser sysUser, String source) {
                return R.fail("人脸登录失败:" + throwable.getMessage());
            }

            @Override
            public R<SysUser> findByUserId(Long userId) {
                return R.fail("查询信息失败:" + throwable.getMessage());
            }
        };

    }
}
